package edu.mit.harold.icollections;

import java.util.Map;
import java.util.Map.Entry;




/**
 *
 * A static convenience class for creating efficient immutable maps.
 * <p>
 * This class simply creates HashIMaps backed by IntTreeIMaps.
 * 
 * @author harold
 */
public final class HashTreeIMap {
	// not instantiable (or subclassable):
	private HashTreeIMap() {}
	
	private static final HashIMap<Object,Object> EMPTY
		= HashIMap.empty(IntTreeIMap.<ISequence<Entry<Object,Object>>>empty());

	/**
	 * @param <K>
	 * @param <V>
	 * @return an empty map
	 */
	@SuppressWarnings("unchecked")
	public static <K,V> HashIMap<K,V> empty() {
		return (HashIMap<K,V>)EMPTY; }
	
	/**
	 * @param <K>
	 * @param <V>
	 * @param key
	 * @param value
	 * @return empty().plus(key, value)
	 */
	public static <K,V> HashIMap<K,V> singleton(final K key, final V value) {
		return HashTreeIMap.<K,V>empty().plus(key, value); }
	
	/**
	 * @param <K>
	 * @param <V>
	 * @param map
	 * @return empty().plusAll(map)
	 */
	public static <K,V> HashIMap<K,V> from(final Map<? extends K, ? extends V> map) {
		return HashTreeIMap.<K,V>empty().plusAll(map); }
}
